@@ -78,7 +78,7 @@ public:
      * Closes storage, freeing all allocated resources. Called from destructor, so you don't need to call it directly.
      * @return true on success.
      */
-    bool close() override;
+    void close() override;
 
     /**
      * @return Article archive for feed at given url.
@@ -87,29 +87,20 @@ public:
     const FeedStorage *archiveFor(const QString &url) const override;
 
     bool autoCommit() const override;
-    int unreadFor(const QString &url) const override;
-    void setUnreadFor(const QString &url, int unread) override;
-    int totalCountFor(const QString &url) const override;
-    void setTotalCountFor(const QString &url, int total) override;
-    int lastFetchFor(const QString &url) const override;
-    void setLastFetchFor(const QString &url, int lastFetch) override;
+
+    // API for FeedStorage to alter the feed index 'view'
+    int unreadFor(const QString &url) const;
+    void setUnreadFor(const QString &url, int unread);
+    int totalCountFor(const QString &url) const;
+    void setTotalCountFor(const QString &url, int total);
+    QDateTime lastFetchFor(const QString &url) const;
+    void setLastFetchFor(const QString &url, const QDateTime &lastFetch);
 
     QStringList feeds() const override;
 
     void storeFeedList(const QString &opmlStr) override;
     QString restoreFeedList() const override;
 
-    void storeTagSet(const QString &xmlStr) override;
-    QString restoreTagSet() const override;
-
-    /** adds all feed storages from a source to this storage
-        existing articles are replaced
-    */
-    void add(Storage *source) override;
-
-    /** deletes all feed storages in this archive */
-    void clear() override;
-
     void markDirty();
 
 protected Q_SLOTS:
