@@ -245,7 +245,9 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
 
     //Initialize instance.
     (void)UnityServiceManager::instance();
-    connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, UnityServiceManager::instance(), &UnityServiceManager::slotSetUnread);
+    if (Settings::showUnreadInTaskbar()) {
+        connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, UnityServiceManager::instance(), &UnityServiceManager::slotSetUnread);
+    }
 
     if (Settings::showTrayIcon() && !TrayIcon::getInstance()) {
         initializeTrayIcon();
@@ -339,6 +341,14 @@ void Part::initializeTrayIcon()
 
 void Part::slotSettingsChanged()
 {
+    if (Settings::showUnreadInTaskbar()) {
+        connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, UnityServiceManager::instance(), &UnityServiceManager::slotSetUnread);
+        m_mainWidget->slotSetTotalUnread();
+    } else {
+        disconnect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, UnityServiceManager::instance(), &UnityServiceManager::slotSetUnread);
+        UnityServiceManager::instance()->slotSetUnread(0);
+    }
+
     NotificationManager::self()->setWidget(isTrayIconEnabled() ? m_mainWidget->window() : nullptr, componentData().componentName());
 
     if (Settings::showTrayIcon()) {
@@ -353,6 +363,8 @@ void Part::slotSettingsChanged()
         m_actionManager->setTrayIcon(nullptr);
     }
 
+
+
     const QStringList fonts {
         Settings::standardFont(),
         Settings::fixedFont(),
@@ -650,10 +662,10 @@ void Part::showOptions()
 
     if (!m_dialog) {
         m_dialog = new KCMultiDialog(m_mainWidget);
-        connect(m_dialog, QOverload<>::of(&KCMultiDialog::configCommitted),
+        connect(m_dialog, qOverload<>(&KCMultiDialog::configCommitted),
                 this, &Part::slotSettingsChanged);
         if (TrayIcon::getInstance()) {
-            connect(m_dialog, QOverload<>::of(&KCMultiDialog::configCommitted),
+            connect(m_dialog, qOverload<>(&KCMultiDialog::configCommitted),
                     TrayIcon::getInstance(), &TrayIcon::settingsChanged);
         }
 
@@ -740,7 +752,8 @@ bool Part::handleCommandLine(const QStringList &args)
     QStringList feedsToAdd = parser.values(QStringLiteral("addfeed"));
 
     if (feedsToAdd.isEmpty() && !parser.positionalArguments().isEmpty()) {
-        Q_FOREACH (QString url, parser.positionalArguments()) {
+        const auto positionalArguments = parser.positionalArguments();
+        for (QString url : positionalArguments) {
             const QUrl tempUrl = QUrl::fromUserInput(url);
             if (tempUrl.isLocalFile()) {
                 const QString tempLocalFile = tempUrl.toLocalFile();
