@@ -67,7 +67,7 @@ using namespace Akregator::Filters;
 ArticleViewerWidget::ArticleViewerWidget(const QString &grantleeDirectory, KActionCollection *ac, QWidget *parent)
     : QWidget(parent)
     , m_imageDir(QUrl::fromLocalFile(QString(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/akregator/Media/"))))
-    , m_node(0)
+    , m_node(nullptr)
     , m_viewMode(NormalView)
     , m_articleViewerWidgetNg(new Akregator::ArticleViewerWebEngineWidgetNg(ac, this))
     , m_grantleeDirectory(grantleeDirectory)
@@ -193,6 +193,9 @@ void ArticleViewerWidget::showArticle(const Akregator::Article &article)
         return;
     }
 
+    const QUrl xmlUrl = QUrl(article.feed()->xmlUrl());
+    qCDebug(AKREGATOR_LOG) << "showing Article - xmlUrl:" << xmlUrl;
+    m_articleHtmlWriter->setBaseUrl(xmlUrl);
     m_viewMode = NormalView;
     disconnectFromNode(m_node);
     m_article = article;
