@@ -60,7 +60,7 @@ class MainWindow : public KParts::MainWindow
     Q_OBJECT
 public:
     explicit MainWindow(QWidget *parent = nullptr);
-    ~MainWindow();
+    ~MainWindow() override;
 
     /**
      * Creates the progress widget in the status bar and the ProgressDialog
